#ifndef UNISTD_H
#define UNISTD_H

typedef long off_t;

int close (int fd);
int open(const char *path, int mode);
int open(const char *path, int access, unsigned mode);
int read(int fd, void* buf, size_t count);
int write(int fd, const void * buf, size_t count);
off_t lseek(int fildes, off_t offset, int whence);
int access(const char* path, int mode);
#define unlink ::remove

#endif
